[][src]Module shadowsocks::plugin

Plugin (SIP003)

+------------+                    +---------------------------+
|  SS Client +-- Local Loopback --+  Plugin Client (Tunnel)   +--+
+------------+                    +---------------------------+  |
                                                                 |
            Public Internet (Obfuscated/Transformed traffic) ==> |
                                                                 |
+------------+                    +---------------------------+  |
|  SS Server +-- Local Loopback --+  Plugin Server (Tunnel)   +--+
+------------+                    +---------------------------+

Structs

PluginConfig

Config for plugin

Enums

PluginMode

Mode of Plugin

Functions

launch_plugins

Launch plugins in config. Returns a future that completes when any plugin terminates or there were an error in watching the subprocess. Returns None if no plugins were launched.