Module shadowsocks::crypto::stream [] [src]

Stream ciphers

Enums

StreamCipherVariant

Variant cipher which contains all possible ciphers

Traits

StreamCipher

Basic operation of Cipher, which is a Symmetric Cipher.

Functions

new_stream

Generate a specific Cipher with key and initialize vector