[−][src]Function shadowsocks::plugin::launch_plugins
pub fn launch_plugins(
config: &mut Config,
mode: PluginMode
) -> Result<Option<impl Future<Item = (), Error = Error>>>
Launch plugins in config. Returns a future that completes when any plugin terminates
or there were an error in watching the subprocess. Returns None if no plugins
were launched.